Index: trunk/src/bindings/interface/ScriptMgr.h
===================================================================
--- trunk/src/bindings/interface/ScriptMgr.h (revision 2)
+++ trunk/src/bindings/interface/ScriptMgr.h (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
@@ -87,5 +89,5 @@
 #define VISIBLE_RANGE (50.0f)
 
-struct MANGOS_DLL_DECL ScriptedAI : public CreatureAI
+struct TRINITY_DLL_DECL ScriptedAI : public CreatureAI
 {
     ScriptedAI(Creature* creature) : m_creature(creature) {}
Index: trunk/src/bindings/interface/system.cpp
===================================================================
--- trunk/src/bindings/interface/system.cpp (revision 2)
+++ trunk/src/bindings/interface/system.cpp (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
Index: trunk/src/bindings/interface/Scripts/sc_defines.cpp
===================================================================
--- trunk/src/bindings/interface/Scripts/sc_defines.cpp (revision 2)
+++ trunk/src/bindings/interface/Scripts/sc_defines.cpp (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
Index: trunk/src/bindings/interface/Scripts/sc_defines.h
===================================================================
--- trunk/src/bindings/interface/Scripts/sc_defines.h (revision 2)
+++ trunk/src/bindings/interface/Scripts/sc_defines.h (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
Index: trunk/src/bindings/interface/Scripts/sc_default.cpp
===================================================================
--- trunk/src/bindings/interface/Scripts/sc_default.cpp (revision 2)
+++ trunk/src/bindings/interface/Scripts/sc_default.cpp (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
Index: trunk/src/bindings/interface/Makefile.am
===================================================================
--- trunk/src/bindings/interface/Makefile.am (revision 23)
+++ trunk/src/bindings/interface/Makefile.am (revision 44)
@@ -5,5 +5,5 @@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
@@ -53,2 +53,3 @@
         Readme.txt
 
+
Index: trunk/src/bindings/interface/ScriptMgr.cpp
===================================================================
--- trunk/src/bindings/interface/ScriptMgr.cpp (revision 2)
+++ trunk/src/bindings/interface/ScriptMgr.cpp (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
@@ -35,5 +37,5 @@
 // -------------------
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 void ScriptsFree()
 {                                                           // Free resources before library unload
@@ -48,5 +50,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 void ScriptsInit()
 {
@@ -77,5 +79,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GossipHello ( Player * player, Creature *_Creature )
 {
@@ -87,5 +89,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GossipSelect( Player *player, Creature *_Creature,uint32 sender, uint32 action )
 {
@@ -99,5 +101,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GossipSelectWithCode( Player *player, Creature *_Creature, uint32 sender, uint32 action, const char* sCode )
 {
@@ -111,5 +113,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool QuestAccept( Player *player, Creature *_Creature, Quest *_Quest )
 {
@@ -121,5 +123,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool QuestSelect( Player *player, Creature *_Creature, Quest *_Quest )
 {
@@ -131,5 +133,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool QuestComplete( Player *player, Creature *_Creature, Quest *_Quest )
 {
@@ -141,5 +143,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ChooseReward( Player *player, Creature *_Creature, Quest *_Quest, uint32 opt )
 {
@@ -151,5 +153,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 uint32 NPCDialogStatus( Player *player, Creature *_Creature )
 {
@@ -161,5 +163,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 uint32 GODialogStatus( Player *player, GameObject *_GO )
 {
@@ -173,5 +175,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ItemHello( Player *player, Item *_Item, Quest *_Quest )
 {
@@ -185,5 +187,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ItemQuestAccept( Player *player, Item *_Item, Quest *_Quest )
 {
@@ -197,5 +199,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GOHello( Player *player, GameObject *_GO )
 {
@@ -209,5 +211,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GOQuestAccept( Player *player, GameObject *_GO, Quest *_Quest )
 {
@@ -221,5 +223,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GOChooseReward( Player *player, GameObject *_GO, Quest *_Quest, uint32 opt )
 {
@@ -233,5 +235,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool AreaTrigger      ( Player *player, AreaTriggerEntry* atEntry )
 {
@@ -244,5 +246,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ReceiveEmote ( Player *player, Creature *_Creature, uint32 emote )
 {
@@ -253,5 +255,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ItemUse( Player *player, Item* _Item, SpellCastTargets const& targets)
 {
@@ -264,5 +266,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 CreatureAI* GetAI(Creature *_Creature )
 {
@@ -273,5 +275,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 InstanceData* CreateInstanceData(Map *map)
 {
Index: trunk/src/bindings/interface/config.h
===================================================================
--- trunk/src/bindings/interface/config.h (revision 2)
+++ trunk/src/bindings/interface/config.h (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
@@ -24,8 +26,8 @@
 #ifdef WIN32
 //#include <windows.h>
-#define MANGOS_DLL_EXPORT extern "C" __declspec(dllexport)
+#define TRINITY_DLL_EXPORT extern "C" __declspec(dllexport)
 #elif defined( __GNUC__ )
-#define MANGOS_DLL_EXPORT extern "C"
+#define TRINITY_DLL_EXPORT extern "C"
 #else
-#define MANGOS_DLL_EXPORT extern "C" export
+#define TRINITY_DLL_EXPORT extern "C" export
 #endif
Index: trunk/src/bindings/scripts/sql/Makefile.in
===================================================================
--- trunk/src/bindings/scripts/sql/Makefile.in (revision 24)
+++ trunk/src/bindings/scripts/sql/Makefile.in (revision 44)
@@ -21,5 +21,5 @@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
Index: trunk/src/bindings/scripts/sql/Makefile.am
===================================================================
--- trunk/src/bindings/scripts/sql/Makefile.am (revision 23)
+++ trunk/src/bindings/scripts/sql/Makefile.am (revision 44)
@@ -5,5 +5,5 @@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
Index: trunk/src/bindings/scripts/ScriptMgr.h
===================================================================
--- trunk/src/bindings/scripts/ScriptMgr.h (revision 37)
+++ trunk/src/bindings/scripts/ScriptMgr.h (revision 44)
@@ -1,3 +1,6 @@
-/* Copyright (C) 2006 - 2008 ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+/* Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+ *
  * This program is free software licensed under GPL version 2
  * Please see the included DOCS/LICENSE.TXT for more information */
@@ -79,9 +82,9 @@
 
 #ifdef WIN32
-  #define MANGOS_DLL_EXPORT extern "C" __declspec(dllexport)
+  #define TRINITY_DLL_EXPORT extern "C" __declspec(dllexport)
 #elif defined( __GNUC__ )
-  #define MANGOS_DLL_EXPORT extern "C"
+  #define TRINITY_DLL_EXPORT extern "C"
 #else
-  #define MANGOS_DLL_EXPORT extern "C" export
+  #define TRINITY_DLL_EXPORT extern "C" export
 #endif
 
Index: trunk/src/bindings/scripts/include/sc_gossip.h
===================================================================
--- trunk/src/bindings/scripts/include/sc_gossip.h (revision 37)
+++ trunk/src/bindings/scripts/include/sc_gossip.h (revision 44)
@@ -1,3 +1,6 @@
-/* Copyright (C) 2006 - 2008 ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+/* Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+ *
  * This program is free software licensed under GPL version 2
  * Please see the included DOCS/LICENSE.TXT for more information */
Index: trunk/src/bindings/scripts/include/sc_instance.h
===================================================================
--- trunk/src/bindings/scripts/include/sc_instance.h (revision 2)
+++ trunk/src/bindings/scripts/include/sc_instance.h (revision 44)
@@ -23,5 +23,5 @@
 #define OUT_LOAD_INST_DATA_FAIL        error_log("SD2: Unable to load Instance Data for Instance %s (Map %d, Instance Id: %d).",instance->GetMapName(), instance->GetId(), instance->GetInstanceId())
 
-class MANGOS_DLL_DECL ScriptedInstance : public InstanceData
+class TRINITY_DLL_DECL ScriptedInstance : public InstanceData
 {
     public:
Index: trunk/src/bindings/scripts/include/sc_creature.cpp
===================================================================
--- trunk/src/bindings/scripts/include/sc_creature.cpp (revision 37)
+++ trunk/src/bindings/scripts/include/sc_creature.cpp (revision 44)
@@ -1,3 +1,6 @@
-/* Copyright (C) 2006 - 2008 ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+/* Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+ *
  * This program is free software licensed under GPL version 2
  * Please see the included DOCS/LICENSE.TXT for more information */
@@ -507,5 +510,5 @@
 Unit* ScriptedAI::DoSelectLowestHpFriendly(float range, uint32 MinHPDiff)
 {
-    CellPair p(MaNGOS::ComputeCellPair(m_creature->GetPositionX(), m_creature->GetPositionY()));
+    CellPair p(Trinity::ComputeCellPair(m_creature->GetPositionX(), m_creature->GetPositionY()));
     Cell cell(p);
     cell.data.Part.reserved = ALL_DISTRICT;
@@ -514,6 +517,6 @@
     Unit* pUnit = NULL;
 
-    MaNGOS::MostHPMissingInRange u_check(m_creature, range, MinHPDiff);
-    MaNGOS::UnitLastSearcher<MaNGOS::MostHPMissingInRange> searcher(pUnit, u_check);
+    Trinity::MostHPMissingInRange u_check(m_creature, range, MinHPDiff);
+    Trinity::UnitLastSearcher<Trinity::MostHPMissingInRange> searcher(pUnit, u_check);
 
     /*
@@ -521,5 +524,5 @@
     This means that if we only search grid then we cannot possibly return pets or players so this is safe
     */
-    TypeContainerVisitor<MaNGOS::UnitLastSearcher<MaNGOS::MostHPMissingInRange>, GridTypeMapContainer >  grid_unit_searcher(searcher);
+    TypeContainerVisitor<Trinity::UnitLastSearcher<Trinity::MostHPMissingInRange>, GridTypeMapContainer >  grid_unit_searcher(searcher);
 
     CellLock<GridReadGuard> cell_lock(cell, p);
@@ -530,5 +533,5 @@
 std::list<Creature*> ScriptedAI::DoFindFriendlyCC(float range)
 {
-    CellPair p(MaNGOS::ComputeCellPair(m_creature->GetPositionX(), m_creature->GetPositionY()));
+    CellPair p(Trinity::ComputeCellPair(m_creature->GetPositionX(), m_creature->GetPositionY()));
     Cell cell(p);
     cell.data.Part.reserved = ALL_DISTRICT;
@@ -537,8 +540,8 @@
     std::list<Creature*> pList;
 
-    MaNGOS::FriendlyCCedInRange u_check(m_creature, range);
-    MaNGOS::CreatureListSearcher<MaNGOS::FriendlyCCedInRange> searcher(pList, u_check);
-
-    TypeContainerVisitor<MaNGOS::CreatureListSearcher<MaNGOS::FriendlyCCedInRange>, GridTypeMapContainer >  grid_creature_searcher(searcher);
+    Trinity::FriendlyCCedInRange u_check(m_creature, range);
+    Trinity::CreatureListSearcher<Trinity::FriendlyCCedInRange> searcher(pList, u_check);
+
+    TypeContainerVisitor<Trinity::CreatureListSearcher<Trinity::FriendlyCCedInRange>, GridTypeMapContainer >  grid_creature_searcher(searcher);
 
     CellLock<GridReadGuard> cell_lock(cell, p);
@@ -550,5 +553,5 @@
 std::list<Creature*> ScriptedAI::DoFindFriendlyMissingBuff(float range, uint32 spellid)
 {
-    CellPair p(MaNGOS::ComputeCellPair(m_creature->GetPositionX(), m_creature->GetPositionY()));
+    CellPair p(Trinity::ComputeCellPair(m_creature->GetPositionX(), m_creature->GetPositionY()));
     Cell cell(p);
     cell.data.Part.reserved = ALL_DISTRICT;
@@ -557,8 +560,8 @@
     std::list<Creature*> pList;
 
-    MaNGOS::FriendlyMissingBuffInRange u_check(m_creature, range, spellid);
-    MaNGOS::CreatureListSearcher<MaNGOS::FriendlyMissingBuffInRange> searcher(pList, u_check);
-
-    TypeContainerVisitor<MaNGOS::CreatureListSearcher<MaNGOS::FriendlyMissingBuffInRange>, GridTypeMapContainer >  grid_creature_searcher(searcher);
+    Trinity::FriendlyMissingBuffInRange u_check(m_creature, range, spellid);
+    Trinity::CreatureListSearcher<Trinity::FriendlyMissingBuffInRange> searcher(pList, u_check);
+
+    TypeContainerVisitor<Trinity::CreatureListSearcher<Trinity::FriendlyMissingBuffInRange>, GridTypeMapContainer >  grid_creature_searcher(searcher);
 
     CellLock<GridReadGuard> cell_lock(cell, p);
Index: trunk/src/bindings/scripts/system.cpp
===================================================================
--- trunk/src/bindings/scripts/system.cpp (revision 2)
+++ trunk/src/bindings/scripts/system.cpp (revision 44)
@@ -1,4 +1,6 @@
 /* 
- * Copyright (C) 2005-2008 MaNGOS <http://www.mangosproject.org/>
+ * Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: MaNGOS <http://www.mangosproject.org/>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -9,10 +11,10 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
Index: trunk/src/bindings/scripts/Makefile.am
===================================================================
--- trunk/src/bindings/scripts/Makefile.am (revision 43)
+++ trunk/src/bindings/scripts/Makefile.am (revision 44)
@@ -5,5 +5,5 @@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
@@ -416,2 +416,3 @@
 
 
+
Index: trunk/src/bindings/scripts/ScriptMgr.cpp
===================================================================
--- trunk/src/bindings/scripts/ScriptMgr.cpp (revision 41)
+++ trunk/src/bindings/scripts/ScriptMgr.cpp (revision 44)
@@ -634,5 +634,5 @@
     // Load Script Text 
     outstring_log("TSCR: Loading Script Texts...");
-    LoadMangosStrings(TScriptDB,"script_texts",TEXT_SOURCE_RANGE,(TEXT_SOURCE_RANGE*2)+1);
+    LoadTrinityStrings(TScriptDB,"script_texts",TEXT_SOURCE_RANGE,(TEXT_SOURCE_RANGE*2)+1);
 
     // Gather Additional data from Script Texts
@@ -698,5 +698,5 @@
     // Load Custom Text 
     outstring_log("TSCR: Loading Custom Texts...");
-    LoadMangosStrings(TScriptDB,"custom_texts",TEXT_SOURCE_RANGE*2,(TEXT_SOURCE_RANGE*3)+1);
+    LoadTrinityStrings(TScriptDB,"custom_texts",TEXT_SOURCE_RANGE*2,(TEXT_SOURCE_RANGE*3)+1);
 
     // Gather Additional data from Custom Texts
@@ -1175,5 +1175,5 @@
 }extern *SpellSummary;
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 void ScriptsFree()
 {   
@@ -1188,5 +1188,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 void ScriptsInit()
 {
@@ -1932,5 +1932,5 @@
 //*** Functions to be Exported ***
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GossipHello ( Player * player, Creature *_Creature )
 {
@@ -1942,5 +1942,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GossipSelect( Player *player, Creature *_Creature, uint32 sender, uint32 action )
 {
@@ -1954,5 +1954,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GossipSelectWithCode( Player *player, Creature *_Creature, uint32 sender, uint32 action, const char* sCode )
 {
@@ -1966,5 +1966,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool QuestAccept( Player *player, Creature *_Creature, Quest const *_Quest )
 {
@@ -1976,5 +1976,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool QuestSelect( Player *player, Creature *_Creature, Quest const *_Quest )
 {
@@ -1986,5 +1986,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool QuestComplete( Player *player, Creature *_Creature, Quest const *_Quest )
 {
@@ -1996,5 +1996,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ChooseReward( Player *player, Creature *_Creature, Quest const *_Quest, uint32 opt )
 {
@@ -2006,5 +2006,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 uint32 NPCDialogStatus( Player *player, Creature *_Creature )
 {
@@ -2016,5 +2016,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 uint32 GODialogStatus( Player *player, GameObject *_GO )
 {
@@ -2026,5 +2026,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ItemHello( Player *player, Item *_Item, Quest const *_Quest )
 {
@@ -2036,5 +2036,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ItemQuestAccept( Player *player, Item *_Item, Quest const *_Quest )
 {
@@ -2046,5 +2046,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GOHello( Player *player, GameObject *_GO )
 {
@@ -2056,5 +2056,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GOQuestAccept( Player *player, GameObject *_GO, Quest const *_Quest )
 {
@@ -2066,5 +2066,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool GOChooseReward( Player *player, GameObject *_GO, Quest const *_Quest, uint32 opt )
 {
@@ -2076,5 +2076,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool AreaTrigger( Player *player, AreaTriggerEntry * atEntry)
 {
@@ -2087,5 +2087,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 CreatureAI* GetAI(Creature *_Creature)
 {
@@ -2096,5 +2096,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ItemUse( Player *player, Item* _Item, SpellCastTargets const& targets)
 {
@@ -2105,5 +2105,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 bool ReceiveEmote( Player *player, Creature *_Creature, uint32 emote )
 {
@@ -2114,5 +2114,5 @@
 }
 
-MANGOS_DLL_EXPORT
+TRINITY_DLL_EXPORT
 InstanceData* CreateInstanceData(Map *map)
 {
Index: trunk/src/bindings/Makefile.am
===================================================================
--- trunk/src/bindings/Makefile.am (revision 23)
+++ trunk/src/bindings/Makefile.am (revision 44)
@@ -5,5 +5,5 @@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #

Index: trunk/src/bindings/scripts/include/sc_creature.h
===================================================================
--- trunk/src/bindings/scripts/include/sc_creature.h (revision 14)
+++ trunk/src/bindings/scripts/include/sc_creature.h (revision 44)
@@ -1,3 +1,6 @@
-/* Copyright (C) 2006 - 2008 ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+/* Copyright (C) 2008 Trinity <http://www.trinitycore.org/>
+ *
+ * Thanks to the original authors: ScriptDev2 <https://scriptdev2.svn.sourceforge.net/>
+ *
  * This program is free software licensed under GPL version 2
  * Please see the included DOCS/LICENSE.TXT for more information */
@@ -9,5 +12,5 @@
 #include "Creature.h"
 
-struct MANGOS_DLL_DECL ScriptedAI : public CreatureAI
+struct TRINITY_DLL_DECL ScriptedAI : public CreatureAI
 {
     ScriptedAI(Creature* creature) : m_creature(creature), InCombat(false) {}
@@ -27,5 +30,5 @@
     void EnterEvadeMode();
 
     //Called at any heal cast/item used (call non implemented in mangos)
     void HealBy(Unit *healer, uint32 amount_healed) {}
 
@@ -154,5 +157,5 @@
 };
 
-struct MANGOS_DLL_DECL Scripted_NoMovementAI : public ScriptedAI
+struct TRINITY_DLL_DECL Scripted_NoMovementAI : public ScriptedAI
 {
     Scripted_NoMovementAI(Creature* creature) : ScriptedAI(creature) {}
@@ -27,5 +30,5 @@
     void EnterEvadeMode();
 
-    //Called at any heal cast/item used (call non implemented in mangos)
+    //Called at any heal cast/item used (call non implemented in Trinity)
     void HealBy(Unit *healer, uint32 amount_healed) {}
 